package cn.bunny.controller;


import cn.bunny.common.spzx.model.dto.system.SysUserDto;
import cn.bunny.common.spzx.model.entity.system.SysUser;
import cn.bunny.common.spzx.model.vo.common.Result;
import cn.bunny.common.spzx.model.vo.common.ResultCodeEnum;
import cn.bunny.service.SysUserService;
import com.github.pagehelper.PageInfo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@RestController
@Tag(name = "用户管理接口")
@RequestMapping(value = "/admin/system/sysUser")
public class SysUserController {
    @Autowired
    private SysUserService sysUserService;

    @Operation(summary = "查询用户列表", description = "查询用户列表，包含关键字分页器")
    @GetMapping(value = "findByPage/{pageNum}/{pageSize}")
    public Result findByPage(@PathVariable("pageNum") Integer pageNum, @PathVariable("pageSize") Integer pageSize, SysUserDto sysUserDto) {
        PageInfo<SysUser> pageInfo = sysUserService.findByPage(pageNum, pageSize, sysUserDto);
        return Result.build(pageInfo, ResultCodeEnum.SUCCESS);
    }

    @Operation(summary = "用户添加", description = "添加用户")
    @PostMapping("saveSysuser")
    public Result saveSysuser(@RequestBody SysUser sysUser) {
        sysUserService.saveSysuser(sysUser);
        return Result.build(null, ResultCodeEnum.SUCCESS);
    }

    @Operation(summary = "用户修改", description = "修改用户信息")
    @PutMapping("updateSysUser")
    public Result updateSysUser(@RequestBody SysUser sysUser) {
        sysUserService.updateSysUser(sysUser);
        return Result.build(null, ResultCodeEnum.SUCCESS);
    }

    @Operation(summary = "删除用户", description = "删除用户将status改为1")
    @PutMapping("deleteUserById/{userId}")
    public Result deleteUserById(@PathVariable("userId") Integer userId) {
        sysUserService.deleteUserById(userId);
        return Result.build(null, ResultCodeEnum.SUCCESS);
    }
}
